OC.L10N.register(
    "files_sharing",
    {
    "Waiting…" : "منتظر باشید ...",
    "error" : "خطا",
    "finished" : "تمام شد",
    "This will stop your current uploads." : "با این کار آپلودهای فعلی شما متوقف خواهد شد.",
    "Move or copy" : "انتقال یا کپی",
    "Download" : "دانلود",
    "Delete" : "حذف",
    "You can upload into this folder" : "می‌توانید در این پوشه آپلود کنید",
    "Terms of service" : "شرایط و قوانین",
    "Show list view" : "نمایش فهرستی",
    "Show grid view" : "نمایش شبکه‌ای",
    "No compatible server found at {remote}" : "هیچ سرور سازگار در {از راه دور} یافت نشد",
    "Invalid server URL" : "ادرس سرور نامعتبر",
    "Failed to add the public link to your Nextcloud" : "خطا در افزودن ادرس عمومی به نکس کلود شما",
    "File shares" : "اشتراک گذاری های فایل",
    "Downloaded via public link" : "بارگزاری شده توسط ادرس عمومی ",
    "Downloaded by {email}" : "بارگذاری شده توسط {email}",
    "{file} downloaded via public link" : "{file} توسط آدرس عمومی بارگزاری شد",
    "{email} downloaded {file}" : "{email} فایل {file} را بارگزاری کرد",
    "Shared with group {group}" : "اشتراک گذاری شد با گروه{گروه} ",
    "Removed share for group {group}" : "اشتراک برای گروه حذف شد {گروه}.",
    "{actor} shared with group {group}" : "{بازیگر} با گروه {گروه} به اشتراک گذاشت",
    "{actor} removed share for group {group}" : "{بازیگر} اشتراک را برای {گروه} گروه حذف کرد",
    "Share for group {group} expired" : "اشتراک برای گروه {گروه} منقضی شده است",
    "You shared {file} with group {group}" : "شما {پرونده} را با گروه{گروه} به اشتراک گذاشتید",
    "You removed group {group} from {file}" : "شما گروه {گروه} را از {پرونده} حذف کردید",
    "{actor} shared {file} with group {group}" : "{بازیگر} به اشتراک گذاشته {پرونده} با گروه {گروه}",
    "{actor} removed group {group} from {file}" : "{بازیگر} حذف کرد گروه {گروه} از {پرونده}",
    "Share for file {file} with group {group} expired" : "اشتراک گذاری پرونده{پرونده} با گروه{گروه} منقضی شد",
    "Shared as public link" : "اشتراک گذاشته شده به عنوان ادرس عمومی",
    "Removed public link" : "حذف ادرس عمومی",
    "Public link expired" : "ادرس عمومی منقضی  شد",
    "{actor} shared as public link" : "{بازیگر} به عنوان پیوند عمومی به اشتراک گذاشته شد",
    "{actor} removed public link" : "{actor} ادرس عمومی را حذف کرد",
    "Public link of {actor} expired" : "پیوند عمومی {بازیگر} منقضی شد",
    "You shared {file} as public link" : "شما {پرونده} را به عنوان پیوند عمومی به اشتراک گذاشتید",
    "You removed public link for {file}" : "شما پیوند عمومی را برای {پرونده } حذف کردید",
    "Public link expired for {file}" : "پیوند عمومی برای {پرونده }منقضی شد",
    "{actor} shared {file} as public link" : "{بازیگر }به اشتراک گذاشته {پرونده} به عنوان پیوند عمومی",
    "{actor} removed public link for {file}" : "{بازیگر }پیوند عمومی را برای {پرونده} حذف کرد",
    "Public link of {actor} for {file} expired" : "پیوند عمومی {بازیگر} برای {پرونده} منقضی شد",
    "{user} accepted the remote share" : "{کاربر} سهم از راه دور را پذیرفت",
    "{user} declined the remote share" : "{کاربر }سهم از راه دور را رد کرد",
    "You received a new remote share {file} from {user}" : "شما یک اشتراک از راه دور{پرونده} از {کاربر} در یافت کردید",
    "{user} accepted the remote share of {file}" : "{کاربر }سهم از راه دور {پرونده} را پذیرفت",
    "{user} declined the remote share of {file}" : "{کاربر }سهم از راه دور {پرونده }را رد کرد",
    "{user} unshared {file} from you" : "{کاربر} لغو اشتراک کرد {پرونده} از شما",
    "Shared with {user}" : "اشتراک گذاری با {کاربر}",
    "Removed share for {user}" : "اشتراک برای {کاربر} حذف شد",
    "You removed yourself" : "شما خدتان را حذف کردید",
    "{actor} removed themselves" : "{بازیگر }خود را حذف کردند",
    "{actor} shared with {user}" : "{بازیگر} با {کاربر} به اشتراک گذاشت",
    "{actor} removed share for {user}" : "{بازیگر} اشتراک را برای {کاربر} حذف کرد",
    "Shared by {actor}" : "اشتراک گذاری شده توسط {بازیگر}",
    "{actor} removed share" : "{بازیگر} اشتراک را حذف کرد",
    "Share for {user} expired" : "اشتراک برای {user} منقضی شده است",
    "Share expired" : "اشتراک منقضی شد",
    "You shared {file} with {user}" : "شما {پرونده} را با {کاربر }به اشتراک گذاشتید",
    "You removed {user} from {file}" : "{user} را از {پرونده }حذف کردید",
    "You removed yourself from {file}" : "شما خود را از {file }حذف کردید",
    "{actor} removed themselves from {file}" : "{بازیگر }خود را از {پرونده }حذف کردند",
    "{actor} shared {file} with {user}" : "{بازیگر} به اشتراک گذاشته {پرونده} با {کاربر}",
    "{actor} removed {user} from {file}" : "{بازیگر} حذف کرد {کاربر} از {پرونده}",
    "{actor} shared {file} with you" : "{بازیگر} {پرونده} به اشتراک گذاشته با شما",
    "{actor} removed you from the share named {file}" : "{بازیگر }شما را از اشتراکی به نام {پرونده} حذف کرد",
    "Share for file {file} with {user} expired" : "برای {پرونده }با {کاربر }به اشتراک بگذارید",
    "Share for file {file} expired" : "برای اشتراک {پرونده }منقضی شد",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "یک پرونده یا پوشه به اشتراک گذاشته شده از طریق پست یا از طریق لینک عمومی بارگیری شد",
    "A file or folder was shared from <strong>another server</strong>" : "یک پرونده یا پوشه از سرور دیگر به اشتراک گذاشته شد",
    "Files" : "فایل‌ها",
    "A file or folder has been <strong>shared</strong>" : "فایل یا پوشه ای به <strong>اشتراک</strong> گذاشته شد",
    "Shared link" : "پیوند به اشتراک گذاری شده",
    "Wrong share ID, share does not exist" : "Wrong share ID, share does not exist",
    "Could not delete share" : "اشتراک گذاری حذف نشد",
    "Please specify a file or folder path" : "لطفاً مسیر فایل یا پوشه را مشخص کنید",
    "Wrong path, file/folder does not exist" : "Wrong path, file/folder does not exist",
    "Could not create share" : "امکان ایجاد اشتراک گذاری وجود ندارد",
    "Invalid permissions" : "دسترسی نامعتبر",
    "Please specify a valid user" : "لطفاً یک کاربر معتبر را مشخص کنید",
    "Group sharing is disabled by the administrator" : "اشتراک گروه توسط مدیر غیرفعال شده است.",
    "Please specify a valid group" : "لطفا یک گروه معتبر انتخاب کنید",
    "Public link sharing is disabled by the administrator" : "اشتراک پیوندهای عمومی توسط مدیر غیرفعال شده است",
    "Public upload disabled by the administrator" : "آپلود عمومی توسط سرپرست غیرفعال شده است",
    "Public upload is only possible for publicly shared folders" : "بارگذاری عمومی فقط برای پوشه هایی که به طور عمومی به اشتراک گذاشته می شوند ممکن است",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : ".اشتراک‍‍‍%s ارسال رمز عبور توسط Nextcloud Talk به دلیل فعال نشدن Nextcloud Talk انجام نشد.",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "%2$sاشتراک گذاری%1$s انجام نشد زیرا بک اِند اجازه نمی دهد نوع از سهام استفاده شود",
    "Please specify a valid federated user ID" : "Please specify a valid federated user ID",
    "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر است ، قالب تاریخ باید YYYY-MM-DD باشد",
    "Please specify a valid federated group ID" : "Please specify a valid federated group ID",
    "You cannot share to a Circle if the app is not enabled" : "اگر برنامه فعال نباشد ، نمی توانید در یک حلقه به اشتراک بگذارید",
    "Please specify a valid circle" : "لطفاً یک حلقه معتبر تعیین کنید",
    "Sharing %s failed because the back end does not support room shares" : "اشتراک گذاری %sانجام نشد زیرا قسمت پشتی سهام اتاق را پشتیبانی نمی کند",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Sharing %s failed because the back end does not support ScienceMesh shares",
    "Unknown share type" : "نوع اشتراک ناشناخته",
    "Not a directory" : "این یک پوشه نیست",
    "Could not lock node" : "گره را نمی توان قفل کرد",
    "Could not lock path" : "امکان قفل کردن مسیر وجود ندارد.",
    "Wrong or no update parameter given" : "اشتباهی و یا پارامتر بروزرسانی داده نشد",
    "Share must at least have READ or CREATE permissions" : "Share must at least have READ or CREATE permissions",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Share must have READ permission if UPDATE or DELETE permission is set",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled.",
    "shared by %s" : "اشتراک گذاری شده به میزان %s",
    "Download all files" : "دانلود همه فایل ها",
    "Direct link" : "لینک مستقیم",
    "Add to your %s" : "Add to your %s",
    "Share API is disabled" : "اشتراک API غیرفعال شده است",
    "File sharing" : "اشتراک گذاری پرونده",
    "Share will expire tomorrow" : "اشتراک فردا منقضی می شود",
    "Your share of {node} will expire tomorrow" : "سهم شما از {node }فردا منقضی می شود",
    "You received {share} as a share by {user}" : "{اشتراک} را به عنوان سهم {user }دریافت کردید",
    "You received {share} to group {group} as a share by {user}" : "شما {اشتراک} را به گروه {گروه} به عنوان سهم {user }دریافت کردید",
    "Accept" : "پذیرفتن",
    "Reject" : "رد کردن",
    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "این برنامه کاربران را قادر می سازد تا پرونده ها را در Nextcloud به اشتراک بگذارند. در صورت فعال بودن ، سرپرست می تواند انتخاب کند که گروه ها می توانند فایل ها را به اشتراک بگذارند. کاربران قابل استفاده سپس می توانند فایلها و پوشه ها را با سایر کاربران و گروه های موجود در Nextcloud به اشتراک بگذارند. علاوه بر این ، اگر سرپرست ویژگی پیوند اشتراک را فعال کند ، می توان از یک لینک خارجی برای به اشتراک گذاری فایلها با سایر کاربران خارج از Nextcloud استفاده کرد. Admins همچنین می تواند رمزهای عبور ، تاریخهای انقضا را اعمال کرده و سرور را قادر به اشتراک گذاری سرور از طریق پیوندهای اشتراک گذاری و همچنین به اشتراک گذاری از دستگاههای تلفن همراه کند.\nخاموش کردن ویژگی ، پرونده ها و پوشه های مشترک را در سرور برای همه گیرندگان اشتراک و همچنین در کلاینت های همگام سازی و برنامه های تلفن همراه حذف می کند. اطلاعات بیشتر در مستندات Nextcloud در دسترس است.",
    "Sharing" : "اشتراک گذاری",
    "Accept user and group shares by default" : "به طور پیش فرض سهام کاربران و گروه ها را بپذیرید",
    "Error while toggling options" : "Error while toggling options",
    "Set default folder for accepted shares" : "Set default folder for accepted shares",
    "Reset" : "بازنشاندن",
    "Reset folder to system default" : "بازنشاندن پوشه به حالت پیشفرض سیستم",
    "Choose a default folder for accepted shares" : "انتخاب پوشه پیشفرض برای به اشتراک گذاشته های تایید شده",
    "Invalid path selected" : "مسیر انتخاب شده نامعتبر است",
    "Unknown error" : "خطای ناشناخته",
    "Allow editing" : "اجازه‌ی ویرایش",
    "Read only" : "فقط خواندنی",
    "Allow upload and editing" : "اجازه آپلود و ویرایش",
    "File drop (upload only)" : "انداختن فایل (فقط آپلود)",
    "Custom permissions" : "Custom permissions",
    "Read" : "خواندن",
    "Upload" : "بارگذاری",
    "Edit" : "ویرایش",
    "Bundled permissions" : "Bundled permissions",
    "group" : "گروه",
    "conversation" : "گفتگو",
    "remote" : "از راه دور",
    "remote group" : "گروه از راه دور",
    "guest" : "میهمان",
    "Shared with the group {user} by {owner}" : "با گروه {کاربر} توسط {صاحب}به اشتراک گذاشته می شود",
    "Shared with the conversation {user} by {owner}" : "به اشتراک گذاشته شده با مکالمه {کاربر} توسط {صاحب}",
    "Shared with {user} by {owner}" : "مشترک با {user} توسط {صاحب}",
    "Added by {initiator}" : "اضافه شده توسط {ابتکار}",
    "Via “{folder}”" : "Via “{folder}”",
    "Unshare" : "لغو اشتراک",
    "Internal link" : "پیوند داخلی",
    "Cannot copy, please copy the link manually" : "کپی کردن امکان پذیر نیست ، لطفا پیوند را به صورت دستی کپی کنید",
    "Copy internal link to clipboard" : "Copy internal link to clipboard",
    "Only works for users with access to this folder" : "فقط برای کاربران دارای دسترسی به این پوشه کار می کند",
    "Only works for users with access to this file" : "فقط برای کاربران با دسترسی به این پرونده کار می کند",
    "Link copied" : "پیوند کپی شد",
    "Please enter the following required information before creating the share" : "لطفا قبل از ایجاد اشتراک ، اطلاعات لازم را وارد کنید",
    "Password protection (enforced)" : "محافظت از رمز عبور (اجباری)",
    "Password protection" : "Password protection",
    "Enter a password" : "یک گذرواژه وارد کنید",
    "Expiration date (enforced)" : "تاریخ انقضا (اجباری)",
    "Enter a date" : "تاریخ را وارد کنید",
    "Create share" : "ساختن اشتراک",
    "Cancel" : "لغو",
    "Add another link" : "پیوند دیگری اضافه کنید",
    "Create a new share link" : "پیوند اشتراک گذاری جدیدی ایجاد کنید",
    "{shareWith} by {initiator}" : "{shareWith} by {initiator}",
    "Shared via link by {initiator}" : "از طریق پیوند توسط {ابتکار}",
    "Mail share ({label})" : "Mail share ({label})",
    "Share link ({label})" : "Share link ({label})",
    "Share link ({index})" : "Share link ({index})",
    "Share link" : "Share link",
    "Actions for \"{title}\"" : "Actions for \"{title}\"",
    "Copy public link of \"{title}\" to clipboard" : "Copy public link of \"{title}\" to clipboard",
    "Error, please enter proper password and/or expiration date" : "خطا ، لطفاً رمز عبور مناسب و یا تاریخ انقضا را وارد کنید",
    "Link share created" : "Link share created",
    "Error while creating the share" : "Error while creating the share",
    "View only" : "تنها مشاهده",
    "Can edit" : "توانایی ویرایش",
    "File drop" : "انداختن پرونده",
    "Search for share recipients" : "Search for share recipients",
    "No recommendations. Start typing." : "هیچ توصیه ای نیست شروع به تایپ کنید.",
    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
    "Name or email …" : "Name or email …",
    "Name, email, or Federated Cloud ID …" : "Name, email, or Federated Cloud ID …",
    "Searching …" : "جستجوکردن …",
    "No elements found." : "عنصری یافت نشد",
    "Search globally" : "در سطح جهان جستجو کنید",
    "Guest" : "مهمان",
    "Group" : "گروه",
    "Email" : "رایانامه",
    "Circle" : "حلقه",
    "Talk conversation" : "Talk conversation",
    "Deck board" : "تخته deck",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "روی{سرور}",
    "Advanced settings" : "تنظیمات پیشرفته",
    "Share label" : "Share label",
    "Set password" : "تنظیم گذرواژه",
    "Password" : "گذرواژه",
    "Password expires {passwordExpirationTime}" : "Password expires {passwordExpirationTime}",
    "Password expired" : "Password expired",
    "Set expiration date" : "تنظیم تاریخ انقضا",
    "Expiration date" : "تاریخ انقضا",
    "Hide download" : "پنهان کردن بارگیری",
    "Video verification" : "تأیید صحت ویدیو",
    "Allow download" : "Allow download",
    "Note to recipient" : "یادداشت برای گیرنده",
    "Enter a note for the share recipient" : "برای دریافت کننده اشتراک یک یادداشت وارد کنید",
    "Create" : "ایجاد",
    "Share" : "هم‌رسانی",
    "Share with" : "به اشتراک گذاشتن با",
    "Others with access" : "دیگران با دسترسی",
    "No other users with access found" : "هیچ کاربر دیگری با دسترسی یافت نشد",
    "Toggle list of others with access to this directory" : "لیست دسترسی دیگران به این فهرست را تغییر دهید",
    "Toggle list of others with access to this file" : "لیست سایرین را با دسترسی به این پرونده تغییر دهید",
    "Unable to fetch inherited shares" : "واگذاری سهام ارثی امکان پذیر نیست",
    "Unable to load the shares list" : "لیست سهام بارگیری نمی شود",
    "Expires {relativetime}" : "{زمان نسبی } منقضی می شود",
    "this share just expired." : "این اشتراک تازه منقضی شد",
    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
    "_Accept share_::_Accept shares_" : ["Accept share","Accept shares"],
    "Open in Files" : "در فایل باز کنید",
    "_Reject share_::_Reject shares_" : ["Reject share","Reject shares"],
    "_Restore share_::_Restore shares_" : ["Restore share","Restore shares"],
    "Shared" : "به اشتراک گزاشته شده ",
    "Link to a file" : "پیوند به یک پرونده",
    "Error creating the share: {errorMessage}" : "Error creating the share: {errorMessage}",
    "Error creating the share" : "خطایی در ایجاد اشتراک",
    "Error updating the share: {errorMessage}" : "Error updating the share: {errorMessage}",
    "Error updating the share" : "خطایی در به روزرسانی اشتراک",
    "File \"{path}\" has been unshared" : "File \"{path}\" has been unshared",
    "Folder \"{path}\" has been unshared" : "Folder \"{path}\" has been unshared",
    "Share {propertyName} saved" : "Share {propertyName} saved",
    "Shared by" : "اشتراک گذاشته شده به وسیله",
    "Shared with" : "مشترک با",
    "Password created successfully" : "Password created successfully",
    "Error generating password from password policy" : "Error generating password from password policy",
    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
    "Shared with you and {circle} by {owner}" : "با شما و {حلقه} توسط {مالک }به اشتراک گذاشته شده است",
    "Shared with you and the conversation {conversation} by {owner}" : "با شما و گفتگو {مکالمه} توسط {صاحب }به اشتراک گذاشته شده است",
    "Shared with you in a conversation by {owner}" : "در گفتگو توسط {صاحب} با شما به اشتراک گذاشته شده است",
    "Shares" : "اشتراک گذاری ها",
    "Overview of shared files." : "Overview of shared files.",
    "No shares" : "اشتراک گذاری وجود ندارد",
    "Files and folders you shared or have been shared with you will show up here" : "Files and folders you shared or have been shared with you will show up here",
    "Shared with you" : "موارد به اشتراک گذاشته شده با شما",
    "List of files that are shared with you." : "List of files that are shared with you.",
    "Nothing shared with you yet" : "هیچ موردی با شما به اشتراک گذاشته نشده است",
    "Files and folders others shared with you will show up here" : "Files and folders others shared with you will show up here",
    "Shared with others" : "موارد به اشتراک گذاشته شده با دیگران",
    "List of files that you shared with others." : "List of files that you shared with others.",
    "Nothing shared yet" : "هیچ موردی تاکنون به اشتراک گذاشته نشده است",
    "Files and folders you shared will show up here" : "Files and folders you shared will show up here",
    "Shared by link" : "اشتراک گذاشته شده از طریق لینک",
    "List of files that are shared by link." : "List of files that are shared by link.",
    "No shared links" : "هیچ لینک اشتراک‌گذاری وجود ندارد",
    "Files and folders you shared by link will show up here" : "Files and folders you shared by link will show up here",
    "Deleted shares" : "اشتراک گذاری های حذف شده",
    "List of shares you left." : "List of shares you left.",
    "No deleted shares" : "اشتراک گذاری های حذف نشده",
    "Shares you have left will show up here" : "Shares you have left will show up here",
    "Pending shares" : "اشتراک در حال انتظار ",
    "List of unapproved shares." : "List of unapproved shares.",
    "No pending shares" : "بدون اشتراک در حال انتظار",
    "Shares you have received but not approved will show up here" : "Shares you have received but not approved will show up here",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Name" : "نام",
    "Share time" : "زمان به اشتراک گذاری",
    "Sorry, this link does not seem to work anymore." : "Sorry, this link does not seem to work anymore.",
    "Reasons might be:" : "ممکن است به این دلایل باشد:",
    "the item was removed" : "این مورد حذف شده است",
    "the link expired" : "این لینک منقضی شده است",
    "sharing is disabled" : "قابلیت اشتراک گذاری غیرفعال است",
    "For more info, please ask the person who sent this link." : "برای اطلاعات بیشتر، لطفا از شخصی که این پیوند را ارسال کرده سوال بفرمایید.",
    "Share note" : "یادداشت اشتراک گذاری",
    "Upload files to %s" : "بارگیری پرونده ها به%s",
    "Note" : "یادداشت",
    "Select or drop files" : "پرونده ها را انتخاب یا رها کنید",
    "Uploading files" : "Uploading files",
    "Uploaded files:" : "پرونده های بارگذاری شده:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "%2$sبا بارگذاری پرونده ها ، شما با %1$sشرایط خدمات موافقت می کنید",
    "Add to your Nextcloud" : "به نکست‌کلود خود اضافه کنید",
    "Files and folders others share with you will show up here" : "فایل ها و پوشه های که دیگران با شما به اشتراک گذاشته شده، اینجا نماش داده خواهند شد.",
    "Files and folders you share will show up here" : "فایل ها و پوشه هایی که شما به اشتراک می گذارید در اینجا نمایش داده خواهند شد.",
    "Files and folders you share by link will show up here" : "فایل‌ها و پوشه‌های اشتراک‌گذاشته توسط شما همراه با لینک در اینجا نمایش داده خواهد شد",
    "Shares you deleted will show up here" : "اشتراک گذاری هایی که شما حذف کرده اید اینجا نمایش داده خواهند شد",
    "Shares you have received but not confirmed will show up here" : "سهام شما دریافت کرده اید اما تأیید نشده است در اینجا نشان داده می شود",
    "Shares will show up here" : "موارد به اشتراک گذاری شده اینجا نمایش داده خواهند شد",
    "Restore" : "بازیابی",
    "Something happened. Unable to restore the share." : "موردی پیش آمده است. امکان بازیابی مورد اشتراک گذاری شده وجود ندارد.",
    "Something happened. Unable to accept the share." : "اتفاقی افتاد. امکان اشتراک گذاری وجود ندارد",
    "Something happened. Unable to reject the share." : "اتفاقی افتاد. امکان رد اشتراک وجود ندارد.",
    "No expiration date set" : "تاریخ انقضا ست نشده است",
    "Sharing %s failed because the back end does not support sciencemesh shares" : "Sharing %s failed because the back end does not support sciencemesh shares",
    "Allow creating" : "اجازه ایجاد",
    "Allow deleting" : "اجازه حذف",
    "Allow resharing" : "مجوز اشتراک گذاری مجدد",
    "Expiration date enforced" : "تاریخ انقضا اجرا شده است",
    "Password protect" : "محافظت با گذرواژه",
    "Science Mesh" : "Science Mesh",
    "Update" : "به‌روز رسانی"
},
"nplurals=2; plural=(n > 1);");
